.. _gal-projectiles_and_scaling:

Projectiles and Scaling
=======================

This section provides examples of the use of the :ref:`api-projectile` and :ref:`api-scaling` components of Cratermaker to model projectil populations and projectile-crater size scaling relationships.
